/*
    MIDI Sequencer C++ Library
    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STABLEHEADERS_H_
#define STABLEHEADERS_H_

extern "C" {
#include <alsa/asoundlib.h>
}

#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <limits>

#include <QtCore>
#include <QtGui>

#endif /*STABLEHEADERS_H_*/
